#!/usr/bin/env python
# vim: sts=4 sw=4 et

import os

try:
    import locale
    encoding = locale.getpreferredencoding()
except:
    encoding = 'ascii'

def default_todo():
    ef = os.environ.get('TODO_FILE', None)
    if ef:
        return ef
    return '.todo.ics'

def splittype(uri):
    colon = uri.find(':')
    if colon < 0:
        return (None, uri)
    slash = uri.find('/')
    if slash > 0 and slash < colon:
        return (None, uri)
    return str(uri[:colon]).lower(), uri[colon + 1:]

def islocal(uri):
    type, path = splittype(uri)
    if type is None:
        return uri
    if type == 'file':
        if path.startswith('//'):
            return path[2:]
        else:
            return path

priomap = { 'veryhigh' : 1
          , 'high' : 3
          , 'medium' : 5
          , 'low' : 7
          , 'verylow' : 9
          }

def prio2int(prio):
    if prio in priomap:
        return priomap[prio]
    raise ValueError("No such priority: %s" % prio)

def int2prio(num):
    if num < 2:   return "veryhigh"
    elif num < 4: return "high"
    elif num < 6: return "medium"
    elif num < 8: return "low"
    else:         return "verylow"

def local2utf(str):
    return str.decode(encoding).encode('utf8')

def utf2local(str):
    return str.encode(encoding)

def raw_input_with_default(prompt, default):
    import readline
    def f():
        readline.insert_text(default)
        readline.redisplay()
    readline.set_pre_input_hook(f)
    try:
        return raw_input(prompt)
    finally:
        readline.set_pre_input_hook(None)

